@@ -2,13 +2,13 @@ package Spreadsheet::XLSX::Reader::LibXML::FmtDefault;
 BEGIN {
   $Spreadsheet::XLSX::Reader::LibXML::FmtDefault::AUTHORITY = 'cpan:JANDREW';
 }
-use version; our $VERSION = qv('v0.28.2');
+use version; our $VERSION = qv('v0.30.2');
 
 use	5.010;
 use	Moose::Role;
-requires qw(
-	get_log_space
-);
+###LogSD	requires qw(
+###LogSD		get_log_space
+###LogSD	);
 
 use Types::Standard qw( InstanceOf ArrayRef Str );
 use lib	'../../../../../lib',;
@@ -122,8 +122,6 @@ Spreadsheet::XLSX::Reader::LibXML::FmtDefault - Default xlsx number formats and
     use Moose;
     with 'Spreadsheet::XLSX::Reader::LibXML::FmtDefault';
     
-    sub get_log_space{}
-    
     package main;
     
     my $parser = MyPackage->new;
